@@ -20,9 +20,9 @@ class BitmexClient:
     def __call__(self):
         return self.client
 
-    def get_wallet(self, prop):
+    def get_margin(self, prop):
         try:
-            wallet_balance = self.client.User.User_getWallet().result()[
+            wallet_balance = self.client.User.User_getMargin().result()[
                 0][str(prop)]
             self._last_wallet_balance = wallet_balance
             return wallet_balance
@@ -147,7 +147,7 @@ class BitmexClient:
     @property
     def acc_balance(self):
         try:
-            return self.get_wallet('amount')
+            return self.get_margin('walletBalance')
         except HTTPUnauthorized:
             return False
 
@@ -178,6 +178,7 @@ class BitmexOrder:
         self.props[symbol]['stoploss_id'] = settings.symbols[symbol]['last_order_stoploss_id']
         self.props[symbol]['stop_id'] = settings.symbols[symbol]['last_order_stop_id']
         self.props[symbol]['SL'] = settings.symbols[symbol]['last_order_SL']
+        self.props[symbol]['qty'] = settings.symbols[symbol]['last_order_qty']
         if self.props[symbol]['stoploss_id']:
             try:
                 res = self.client.client.Order.Order_getOrders(
@@ -208,6 +209,7 @@ class BitmexOrder:
         if stop_type == 'normal':
             self.props[symbol]['stop_id'] = id
             settings.symbols[symbol]['last_order_stop_id'] = id
+            settings.symbols[symbol]['last_order_qty'] = self.props[symbol]['qty']
             pickle.dump(settings, file=open(self._settings_path, 'wb'))
         elif stop_type == 'stoploss':  # also save the stoploss
             self.props[symbol]['stoploss_id'] = id
@@ -253,9 +255,11 @@ class BitmexOrder:
                     between_profs += self.between_profits[sym]
                     self.between_profits[sym] = .0
 
-            # real acc balance difference counting the between profits
-            acc_balance_diff = self.entry_acc_balance[symbol] - \
-                current_acc_balance + between_profs
+            # exit account balance - current account balance
+            acc_balance_diff = current_acc_balance - \
+                between_profs - self.entry_acc_balance[symbol]
+            print("current_acc_balance", current_acc_balance, "between_profs", between_profs,
+                  "self.entry_acc_balance[symbol]", self.entry_acc_balance[symbol])
 
             # in acc balance difference
             self.between_profits[symbol] += acc_balance_diff
@@ -264,17 +268,14 @@ class BitmexOrder:
                 self.props[symbol]['initialSL'] - self.props[symbol]['entry'])
             pnl_rr = pnl_points / initial_risk_points
 
-            acc_balance_expected = self.entry_acc_balance[symbol] * (
-                1 + (pnl_rr * acc_pos_size))
-            acc_balance_real = self.entry_acc_balance[symbol] * (
-                1 + (acc_balance_diff / self.entry_acc_balance[symbol]))
+            real_gain = (acc_balance_diff / self.entry_acc_balance[symbol])
+            expected_gain = pnl_rr * acc_pos_size
 
             # slippage is real acc balance change relative - executed pnl percent
-            print("acc_balance_expected", acc_balance_expected, "acc_balance_real", acc_balance_real)
+            print("expected_gain", expected_gain,
+                  "real_gain", real_gain)
             print("Slippage: {}%".format(
-                round((acc_balance_real - acc_balance_expected) / acc_balance_expected * 100, 2)), flush=True)
-
-            self.entry_acc_balance[symbol] = current_acc_balance
+                round((real_gain - expected_gain) / abs(expected_gain) * 100, 2)), flush=True)
         self.props[symbol]['qty'] = 0
 
     def has_position_opened(self, symbol, cp, candlePrice):
@@ -380,6 +381,7 @@ class BitmexOrder:
                 clOrdID=orderId
             ).result()
             self.props[symbol]['wait_stop'] = False
+            self.props[symbol]['qty'] = 0
             return order_res
         except (HTTPBadRequest, HTTPNotFound) as e:
             print("Error canceling order.", e, flush=True)
@@ -393,7 +395,7 @@ class BitmexOrder:
     def bracket_stop_order(self, symbol, orderQty, entry, sl, tp=0):
         try:
             if self.props[symbol]['qty'] != 0:
-                # order is open (shouldn't be) > close old order first
+                print("order is open -> close old order first", flush=True)
                 self.close(symbol)
                 time.sleep(1)
             self.props[symbol]['stop_id'] = self.generate_id(symbol)
@@ -401,8 +403,8 @@ class BitmexOrder:
                 symbol=symbol, ordType='Stop', clOrdID=self.props[symbol]['stop_id'], orderQty=orderQty,
                 stopPx=self.price_decimals(symbol, entry), execInst='LastPrice'
             ).result()
-            self.save_open_id(symbol, self.props[symbol]['stop_id'])
             self.props[symbol]['qty'] = orderQty
+            self.save_open_id(symbol, self.props[symbol]['stop_id'])
             self.props[symbol]['wait_stop'] = True
             self.props[symbol]['SL'] = sl
             self.props[symbol]['initialSL'] = sl
