@@ -49,7 +49,7 @@ def file_create_input(check_exist=True, symbols=['XBTUSD'], broker='bitmex', str
         symbol_settings = {}
         for symbol in symbols:
             pos_size = input(
-                "Choose your Position Size for {} per trade in %: ".format(symbol))
+                "Choose your Position Size for {} per trade in % (0.25 = 10% drawdown risk, 0.5 = 20% drawdown risk, 1.0 = 40% drawdown risk): ".format(symbol))
             pos_size = check_pos_size(pos_size)
             symbol_settings[symbol] = {
                 'position_size': pos_size, 'last_order_stop_id': '', 'last_order_stoploss_id': '', 'last_order_SL': '', 'last_order_qty': ''}
